==> tj-2.7.0.tar.gz: tj-2.7.0/README.md <==
# Project Title

A simple but powerful module that will provide you many useful methods.<br/>



## **Getting Started** <h3>
This module can provide you with powerful functions such as email(...), color_text(...),
take_src(...), convert_currency(...), compress(...), and many more functions, which otherwise,
you would be writing on your own, wasting time as that code had already been
written and is just an **_import_** statement away...

**tj module helps implement
DRY** _(**D**on't **R**epeat **Y**ourself)_
**and KISS** _(**K**eep **I**t **S**imple **S**tupid)_<br/>


### **Prerequisites**<h3>
These are some of the modules required by tj module-

* *cryptography*
* *autopy*
* *colorama*
* *pyAesCrypt*
* *forex-python*
<br/>


### **Installing**<h2>
You can install tj module by using pip.

```
pip install tj
```
And the latest version of the tj module will be installed.
To check if it is installed correctly, try
```
>>>import tj
>>>tj.__version__
'2.7.0'
>>>
```
<br/>


## **Exernal modules used**<h3>
* *[cryptograhy](https://pypi.org/project/cryptography/)* - Used for encryption and decryption methods
* *[pyAesCrypt](https://pypi.org/project/pyAesCrypt/)* - Used for file encryption and decryption
* *[colorama](https://pypi.org/project/colorama/)* - Used to enable terminal colors
* *[autopy](https://pypi.org/project/autopy/)* - Used to capture screenshots
* *[forex-python](https://pypi.org/project/forex-python/)* - Used to fetch currency exchange rates
<br/>

## **Versions**<h3>
You can view **[Versions.md](Versions.md)** to see the version history of this project
in a glimpse.<br/>


## **Contributing**<h3>
Please feel free to contribute and give ideas for this project. You can add any
functions, modules, methods, which you think, can save time or if they provide
solution to a difficult problem.<br/>


## **License**<h4>
This project is licensed under the *MIT License* - see the **[LICENSE.md](LICENSE.md)** file for details<br/>


## **What's new in this version**<h3>
This version: 2.7.0 updated on 2:40 AM 20th Feburary 2019 (Yes, its AM, not PM!!)

* Added _color_text(...)_ function to print text in command-line, in different colors.
* Changed Readme.md file from a simple text file, to a correctly formated .MD file.
* Made **[Versions.md](Versions.md)** file to store version history.
* Resolved minor bugs.
* Added _get_folder_contents(...)_ and _get_folders_in_folder(...)_ functions.
<br/>


## **Authors**<h3>

* **Tushar Jain** - *Repository Maintainer* - [tusharlock10](https://github.com/tusharlock10)

==> tj-2.7.1.tar.gz: tj-2.7.1/README.md <==
# Project Title

A simple but powerful module that will provide you many useful methods.<br/>



## **Getting Started** <h3>
This module can provide you with powerful functions such as email(...), color_text(...),
take_src(...), convert_currency(...), compress(...), and many more functions, which otherwise,
you would be writing on your own, wasting time as that code had already been
written and is just an **_import_** statement away...

**tj module helps implement
DRY** _(**D**on't **R**epeat **Y**ourself)_
**and KISS** _(**K**eep **I**t **S**imple **S**tupid)_<br/>


### **Prerequisites**<h3>
These are some of the modules required by tj module-

* *cryptography*
* *autopy*
* *colorama*
* *pyAesCrypt*
* *forex-python*
<br/>


### **Installing**<h2>
You can install tj module by using pip.

```
pip install tj
```
And the latest version of the tj module will be installed.
To check if it is installed correctly, try
```
>>>import tj
>>>tj.__version__
'2.7.0'
>>>
```
<br/>


## **Exernal modules used**<h3>
* *[cryptograhy](https://pypi.org/project/cryptography/)* - Used for encryption and decryption methods
* *[pyAesCrypt](https://pypi.org/project/pyAesCrypt/)* - Used for file encryption and decryption
* *[colorama](https://pypi.org/project/colorama/)* - Used to enable terminal colors
* *[autopy](https://pypi.org/project/autopy/)* - Used to capture screenshots
* *[forex-python](https://pypi.org/project/forex-python/)* - Used to fetch currency exchange rates
<br/>

## **Versions**<h3>
You can view **[Versions.md](Versions.md)** to see the version history of this project
in a glimpse.<br/>


## **Contributing**<h3>
Please feel free to contribute and give ideas for this project. You can add any
functions, modules, methods, which you think, can save time or if they provide
solution to a difficult problem.<br/>


## **License**<h4>
This project is licensed under the *MIT License* - see the **[LICENSE.md](LICENSE.md)** file for details<br/>


## **What's new in this version**<h3>
**Last Major Release**: 2.7.0 updated on 2:40 AM 20th February 2019 (Yes, its AM, not PM!!)

* Added _color_text(...)_ function to print text in command-line, in different colors.
* Changed Readme.md file from a simple text file, to a correctly formated .MD file.
* Made **[Versions.md](Versions.md)** file to store version history.
* Resolved minor bugs.
* Added _get_folder_contents(...)_ and _get_folders_in_folder(...)_ functions.
<br/>

**This version**: 2.7.1 updated on 04:25 PM 20th February 2019

* Added __author__ attribute
* Removed minor bugs


## **Authors**<h3>

* **Tushar Jain** - *Repository Maintainer* - [tusharlock10](https://github.com/tusharlock10)
